==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/BaseDataSourceDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let BaseDataSourceDescription = /*@__PURE__*/ (() => {
    class BaseDataSourceDescription extends Description {
        constructor() {
            super();
            this.m = false;
            this.l = false;
            this.aj = 0;
            this.ak = 0;
            this.al = 0;
            this.j = false;
            this.f = null;
            this.g = null;
            this.ar = null;
            this.n = false;
            this.p = false;
            this.k = false;
            this.r = false;
            this.q = false;
            this.o = false;
            this.t = false;
            this.s = false;
            this.u = false;
            this.v = false;
            this.aq = null;
            this.ap = null;
        }
        get_type() {
            return "BaseDataSource";
        }
        get type() {
            return this.get_type();
        }
        get isReadOnly() {
            return this.m;
        }
        set isReadOnly(a) {
            this.m = a;
            this.e("IsReadOnly");
        }
        get isBatchingEnabled() {
            return this.l;
        }
        set isBatchingEnabled(a) {
            this.l = a;
            this.e("IsBatchingEnabled");
        }
        get actualCount() {
            return this.aj;
        }
        set actualCount(a) {
            this.aj = a;
            this.e("ActualCount");
        }
        get firstVisibleIndexRequested() {
            return this.ak;
        }
        set firstVisibleIndexRequested(a) {
            this.ak = a;
            this.e("FirstVisibleIndexRequested");
        }
        get lastVisibleIndexRequested() {
            return this.al;
        }
        set lastVisibleIndexRequested(a) {
            this.al = a;
            this.e("LastVisibleIndexRequested");
        }
        get deferAutoRefresh() {
            return this.j;
        }
        set deferAutoRefresh(a) {
            this.j = a;
            this.e("DeferAutoRefresh");
        }
        get primaryKey() {
            return this.f;
        }
        set primaryKey(a) {
            this.f = a;
            this.e("PrimaryKey");
        }
        get propertiesRequested() {
            return this.g;
        }
        set propertiesRequested(a) {
            this.g = a;
            this.e("PropertiesRequested");
        }
        get sectionHeaderDisplayMode() {
            return this.ar;
        }
        set sectionHeaderDisplayMode(a) {
            this.ar = a;
            this.e("SectionHeaderDisplayMode");
        }
        get isSectionCollapsable() {
            return this.n;
        }
        set isSectionCollapsable(a) {
            this.n = a;
            this.e("IsSectionCollapsable");
        }
        get isSectionExpandedDefault() {
            return this.p;
        }
        set isSectionExpandedDefault(a) {
            this.p = a;
            this.e("IsSectionExpandedDefault");
        }
        get includeSummaryRowsInSection() {
            return this.k;
        }
        set includeSummaryRowsInSection(a) {
            this.k = a;
            this.e("IncludeSummaryRowsInSection");
        }
        get isSectionSummaryRowsAtBottom() {
            return this.r;
        }
        set isSectionSummaryRowsAtBottom(a) {
            this.r = a;
            this.e("IsSectionSummaryRowsAtBottom");
        }
        get isSectionHeaderNormalRow() {
            return this.q;
        }
        set isSectionHeaderNormalRow(a) {
            this.q = a;
            this.e("IsSectionHeaderNormalRow");
        }
        get isSectionContentVisible() {
            return this.o;
        }
        set isSectionContentVisible(a) {
            this.o = a;
            this.e("IsSectionContentVisible");
        }
        get shouldEmitSectionHeaders() {
            return this.t;
        }
        set shouldEmitSectionHeaders(a) {
            this.t = a;
            this.e("ShouldEmitSectionHeaders");
        }
        get shouldEmitSectionFooters() {
            return this.s;
        }
        set shouldEmitSectionFooters(a) {
            this.s = a;
            this.e("ShouldEmitSectionFooters");
        }
        get shouldEmitShiftedRows() {
            return this.u;
        }
        set shouldEmitShiftedRows(a) {
            this.u = a;
            this.e("ShouldEmitShiftedRows");
        }
        get shouldEmitSummaryRows() {
            return this.v;
        }
        set shouldEmitSummaryRows(a) {
            this.v = a;
            this.e("ShouldEmitSummaryRows");
        }
        get schemaChangedRef() {
            return this.aq;
        }
        set schemaChangedRef(a) {
            this.aq = a;
            this.e("SchemaChangedRef");
        }
        get rowExpansionChangedRef() {
            return this.ap;
        }
        set rowExpansionChangedRef(a) {
            this.ap = a;
            this.e("RowExpansionChangedRef");
        }
    }
    BaseDataSourceDescription.$t = /*@__PURE__*/ markType(BaseDataSourceDescription, 'BaseDataSourceDescription', Description.$);
    return BaseDataSourceDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/BaseDataSourceDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let BaseDataSourceDescription = /*@__PURE__*/ (() => {
    class BaseDataSourceDescription extends Description {
        get_type() {
            return "BaseDataSource";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.q = false;
            this.p = false;
            this.an = 0;
            this.ao = 0;
            this.ap = 0;
            this.n = false;
            this.h = null;
            this.i = null;
            this.j = null;
            this.ax = null;
            this.r = false;
            this.t = false;
            this.o = false;
            this.v = false;
            this.u = false;
            this.s = false;
            this.x = false;
            this.w = false;
            this.y = false;
            this.z = false;
            this.aw = null;
            this.av = null;
            this.au = null;
            this.at = null;
        }
        get isReadOnly() {
            return this.q;
        }
        set isReadOnly(a) {
            this.q = a;
            this.g("IsReadOnly");
        }
        get isBatchingEnabled() {
            return this.p;
        }
        set isBatchingEnabled(a) {
            this.p = a;
            this.g("IsBatchingEnabled");
        }
        get actualCount() {
            return this.an;
        }
        set actualCount(a) {
            this.an = a;
            this.g("ActualCount");
        }
        get firstVisibleIndexRequested() {
            return this.ao;
        }
        set firstVisibleIndexRequested(a) {
            this.ao = a;
            this.g("FirstVisibleIndexRequested");
        }
        get lastVisibleIndexRequested() {
            return this.ap;
        }
        set lastVisibleIndexRequested(a) {
            this.ap = a;
            this.g("LastVisibleIndexRequested");
        }
        get deferAutoRefresh() {
            return this.n;
        }
        set deferAutoRefresh(a) {
            this.n = a;
            this.g("DeferAutoRefresh");
        }
        get primaryKey() {
            return this.h;
        }
        set primaryKey(a) {
            this.h = a;
            this.g("PrimaryKey");
        }
        get propertiesRequested() {
            return this.i;
        }
        set propertiesRequested(a) {
            this.i = a;
            this.g("PropertiesRequested");
        }
        get schemaIncludedProperties() {
            return this.j;
        }
        set schemaIncludedProperties(a) {
            this.j = a;
            this.g("SchemaIncludedProperties");
        }
        get sectionHeaderDisplayMode() {
            return this.ax;
        }
        set sectionHeaderDisplayMode(a) {
            this.ax = a;
            this.g("SectionHeaderDisplayMode");
        }
        get isSectionCollapsable() {
            return this.r;
        }
        set isSectionCollapsable(a) {
            this.r = a;
            this.g("IsSectionCollapsable");
        }
        get isSectionExpandedDefault() {
            return this.t;
        }
        set isSectionExpandedDefault(a) {
            this.t = a;
            this.g("IsSectionExpandedDefault");
        }
        get includeSummaryRowsInSection() {
            return this.o;
        }
        set includeSummaryRowsInSection(a) {
            this.o = a;
            this.g("IncludeSummaryRowsInSection");
        }
        get isSectionSummaryRowsAtBottom() {
            return this.v;
        }
        set isSectionSummaryRowsAtBottom(a) {
            this.v = a;
            this.g("IsSectionSummaryRowsAtBottom");
        }
        get isSectionHeaderNormalRow() {
            return this.u;
        }
        set isSectionHeaderNormalRow(a) {
            this.u = a;
            this.g("IsSectionHeaderNormalRow");
        }
        get isSectionContentVisible() {
            return this.s;
        }
        set isSectionContentVisible(a) {
            this.s = a;
            this.g("IsSectionContentVisible");
        }
        get shouldEmitSectionHeaders() {
            return this.x;
        }
        set shouldEmitSectionHeaders(a) {
            this.x = a;
            this.g("ShouldEmitSectionHeaders");
        }
        get shouldEmitSectionFooters() {
            return this.w;
        }
        set shouldEmitSectionFooters(a) {
            this.w = a;
            this.g("ShouldEmitSectionFooters");
        }
        get shouldEmitShiftedRows() {
            return this.y;
        }
        set shouldEmitShiftedRows(a) {
            this.y = a;
            this.g("ShouldEmitShiftedRows");
        }
        get shouldEmitSummaryRows() {
            return this.z;
        }
        set shouldEmitSummaryRows(a) {
            this.z = a;
            this.g("ShouldEmitSummaryRows");
        }
        get schemaChangedRef() {
            return this.aw;
        }
        set schemaChangedRef(a) {
            this.aw = a;
            this.g("SchemaChangedRef");
        }
        get rowExpansionChangedRef() {
            return this.av;
        }
        set rowExpansionChangedRef(a) {
            this.av = a;
            this.g("RowExpansionChangedRef");
        }
        get rootSummariesChangedRef() {
            return this.au;
        }
        set rootSummariesChangedRef(a) {
            this.au = a;
            this.g("RootSummariesChangedRef");
        }
        get propertiesRequestedChangedRef() {
            return this.at;
        }
        set propertiesRequestedChangedRef(a) {
            this.at = a;
            this.g("PropertiesRequestedChangedRef");
        }
    }
    BaseDataSourceDescription.$t = /*@__PURE__*/ markType(BaseDataSourceDescription, 'BaseDataSourceDescription', Description.$);
    return BaseDataSourceDescription;
})();
